# Contributing to OFB Python SDK

We love your input! We want to make contributing to this project as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer

## We Develop with Github

We use GitHub to host code, to track issues and feature requests, as well as accept pull requests.

## We Use [Github Flow](https://guides.github.com/introduction/flow/index.html), So All Code Changes Happen Through Pull Requests

Pull requests are the best way to propose changes to the codebase. We actively welcome your pull requests:

1. Fork the repo and create your branch from `main`.
2. Make your own changes.
3. Ensure your commit messages adhere to the [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/) standard, which helps us to automate the changelog generation and semantic versioning. Example commit message: `feat(login): add 'remember me' checkbox`.
4. Make sure your code lints.
5. Optionally, you can sign your commits using GPG or S/MIME to verify your identity. [Here's how to set that up](https://docs.github.com/en/github/authenticating-to-github/signing-commits).
6. Issue that pull request to the 'develop' branch!

## Any contributions you make will be under the MIT Software License

In short, when you submit code changes, your submissions are understood to be under the same [MIT License](LICENSE) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report bugs using Github's [issues](https://github.com/shing-yu/ofb-python-sdk/issues)

We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/shing-yu/ofb-python-sdk/issues/new); it's that easy!

**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
    - Be specific!
    - Give sample code if you can.
- What you expected would happen
- What actually happens
- Notes (possibly including why you think this might be happening, or stuff you tried that didn't work)

People *love* thorough bug reports. I'm not even kidding.

## Use a Consistent Coding Style

You can use any code formatter (like `black` for Python) to make sure your code conforms to our style guides.

## License

By contributing, you agree that your contributions will be licensed under its MIT License.

## References

This document was adapted from the open-source contribution guidelines for [Facebook's Draft](https://github.com/facebook/draft-js/blob/master/CONTRIBUTING.md).
